==> amarok_2.9.0.orig.tar.xz: amarok-2.9.0/src/dbus/mpris2/DBusAmarokApp.h <==
/***********************************************************************
 * Copyright 2012  Alex Merry <alex.merry@kdemail.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/

#ifndef AMAROK_MEDIAPLAYRER2AMAROKAPP_H
#define AMAROK_MEDIAPLAYRER2AMAROKAPP_H

#include "DBusAbstractAdaptor.h"

#include <QDBusObjectPath>
#include <QVariantMap>

namespace Amarok
{
    class DBusAmarokApp : public DBusAbstractAdaptor
    {
        Q_OBJECT
        Q_CLASSINFO("D-Bus Interface", "org.kde.amarok.App")

        public:
            explicit DBusAmarokApp( QObject* parent );
            ~DBusAmarokApp();

        public Q_SLOTS:
            void ShowOSD() const;
            void LoadThemeFile( const QString &path );
    };
}

#endif // AMAROK_MEDIAPLAYRER2AMAROKAPP_H

==> amarok_3.2.2.orig.tar.xz: amarok-3.2.2/src/dbus/mpris2/DBusAmarokApp.h <==
/***********************************************************************
 * Copyright 2012  Alex Merry <alex.merry@kdemail.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/

#ifndef AMAROK_DBUS_AMAROKAPP_H
#define AMAROK_DBUS_AMAROKAPP_H

#include "DBusAbstractAdaptor.h"

#include <QDBusObjectPath>
#include <QVariantMap>

namespace Amarok
{
    class DBusAmarokApp : public DBusAbstractAdaptor
    {
        Q_OBJECT
        Q_CLASSINFO("D-Bus Interface", "org.kde.amarok.App")

        public:
            explicit DBusAmarokApp( QObject* parent );
            ~DBusAmarokApp() override;

        public Q_SLOTS:
            void ShowOSD() const;
            void LoadThemeFile( const QString &path );
    };
}

#endif // AMAROK_DBUS_AMAROKAPP_H
